@@ -30,8 +30,6 @@ sub main {
 
 	my $username;
 	my $password;
-	my $domain;
-	my @paths;
 
 	GetOptions(
 		'username=s' => \$username,
